@@ -6,14 +6,16 @@ import java.io.IOException;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.BitSet;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
-import java.util.logging.Logger;
+import java.util.function.Supplier;
 import javax.swing.Box;
 import javax.swing.JLabel;
 import javax.swing.JOptionPane;
 import uk.ac.starlink.table.DefaultValueInfo;
 import uk.ac.starlink.table.DescribedValue;
+import uk.ac.starlink.table.RowRunner;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.Tables;
 import uk.ac.starlink.table.ValueInfo;
@@ -41,24 +43,25 @@ public class InterMatchSpec extends MatchSpec {
 
     private final int nTable;
     private final MatchEngine engine;
+    private final Supplier<RowRunner> runnerFact;
     private final TupleSelector[] tupleSelectors;
     private final OutputRequirements[] outReqs;
     private StarTable result;
     private int matchCount;
     private RowSubset[] matchSubsets;
 
-    private static final Logger logger =
-        Logger.getLogger( "uk.ac.starlink.topcat.join" );
-
     /**
      * Constructs a new InterMatchSpec.
      *
      * @param  engine   match algorithm object
+     * @param  runnerFact  supplier for RowRunner
      * @param  nTable   number of tables on which this InterMatch will operate
      */
-    public InterMatchSpec( MatchEngine engine, int nTable ) {
+    public InterMatchSpec( MatchEngine engine, Supplier<RowRunner> runnerFact,
+                           int nTable ) {
         this.nTable = nTable;
         this.engine = engine;
+        this.runnerFact = runnerFact;
 
         Box main = Box.createVerticalBox();
         setLayout( new BorderLayout() );
@@ -124,18 +127,16 @@ public class InterMatchSpec extends MatchSpec {
 
         /* Do the matching. */
         MultiJoinType[] joinTypes = getJoinTypes();
-        RowMatcher matcher = new RowMatcher( engine, tables );
+        RowMatcher matcher =
+            RowMatcher.createMatcher( engine, tables, runnerFact.get() );
         matcher.setIndicator( indicator );
         LinkSet matches = matcher.findGroupMatches( joinTypes );
-        if ( ! matches.sort() ) {
-            logger.warning( "Can't sort matches - matched table rows may be "
-                          + "in an unhelpful order" );
-        }
         int nrow = matches.size();
 
         /* Create a new table based on the matched lines we have identified. */
+        Collection<RowLink> links = MatchStarTables.orderLinks( matches );
         result = MatchStarTables
-                .makeJoinTable( bases, matches, false,
+                .makeJoinTable( bases, links, false,
                                 getDefaultFixActions( nTable ), null );
         addMatchMetadata( result, getDescription(), engine, tables );
 
