@@ -18,6 +18,7 @@ import uk.ac.starlink.ttools.cone.SsaConeSearcher;
 import uk.ac.starlink.util.ContentCoding;
 import uk.ac.starlink.util.gui.ShrinkWrapper;
 import uk.ac.starlink.vo.Capability;
+import uk.ac.starlink.vo.RegistryPanel;
 import uk.ac.starlink.vo.SsapTableLoadDialog;
 
 /**
@@ -43,9 +44,8 @@ public class SsaMultiWindow extends DalMultiWindow {
      */
     private static class SsaMultiService implements DalMultiService {
 
-        @SuppressWarnings({"unchecked","rawtypes"})
-        private final JComboBox formatSelector_
-            = new JComboBox( SsapTableLoadDialog.getFormatOptions() );
+        private final JComboBox<String> formatSelector_
+            = new JComboBox<String>( SsapTableLoadDialog.getFormatOptions() );
 
         private final JComponent controlBox_;
 
@@ -112,6 +112,13 @@ public class SsaMultiWindow extends DalMultiWindow {
             return controlBox_;
         }
 
+        public JComponent getVersionComponent() {
+            return null;
+        }
+
+        public void init( RegistryPanel regPanel ) {
+        }
+
         public ConeSearcher createSearcher( URL url, StarTableFactory tfact,
                                             ContentCoding coding ) {
             String format = (String) formatSelector_.getSelectedItem();
